==> haskell-bower-json-1.0.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-AqNaxvqCVoQEFCrCnKacDk
key: bower-json-1.0.0.1-AqNaxvqCVoQEFCrCnKacDk
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
abi: 01ad9c3b431abbbe841dbb0ebdf8b466
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/bower-json-1.0.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-AqNaxvqCVoQEFCrCnKacDk
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    aeson-better-errors-0.9.1.0-6oS04wXkq4d23AN1VkhmqC base-4.9.0.0
    bytestring-0.10.8.1 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-966jWIhSMKREREetw1xEz9
key: bower-json-1.0.0.1-966jWIhSMKREREetw1xEz9
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
abi: 7fc1b70be0d9df06f0d546445a6d945a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/bower-json-1.0.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-966jWIhSMKREREetw1xEz9
depends:
    aeson-1.0.2.1-L9CPp1k63Y0LjsmlB4O5pz
    aeson-better-errors-0.9.1.0-EfPlhdE1BoGALu1Br4F4Ik base-4.9.0.0
    bytestring-0.10.8.1 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
